#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-pretty
version:              0.8.11
visibility:           public
id:                   aeson-pretty-0.8.11-nawxSYmL7TDqr8VRhwNQe
key:                  aeson-pretty-0.8.11-nawxSYmL7TDqr8VRhwNQe
license:              BSD-3-Clause
copyright:            Copyright 2011 Falko Peters
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Falko Peters <falko.peters@gmail.com>
stability:            experimental
homepage:             http://github.com/informatikr/aeson-pretty
synopsis:             JSON pretty-printing library and command-line tool.
description:
    A JSON pretty-printing library compatible with aeson as well as
    a command-line tool to improve readability of streams of JSON data.

    The /library/ provides the function "encodePretty". It is a drop-in
    replacement for aeson'\''s "encode" function, producing JSON-ByteStrings for
    human readers.

    The /command-line tool/ reads JSON from stdin and writes prettified JSON
    to stdout. It also offers a complementary "compact"-mode, essentially the
    opposite of pretty-printing.

category:             Text, Web, JSON, Pretty Printer
abi:                  7107817cbe7749ceeb7347cb99744817
exposed:              True
exposed-modules:      Data.Aeson.Encode.Pretty
import-dirs:          /usr/lib/ghc-9.6.6/site-local/aeson-pretty-0.8.11
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aeson-pretty-0.8.11
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aeson-pretty-0.8.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-pretty
hs-libraries:         HSaeson-pretty-0.8.11-nawxSYmL7TDqr8VRhwNQe
depends:
    aeson-2.2.2.0-Kh0pDn2f78S4mLhsXsZzzT base-4.18.2.1
    base-compat-0.14.1-4heBy5B59ewBpEOwRrJlc4 bytestring-0.11.5.3
    scientific-0.3.8.1-5DbHtB8w5OO3mo7GyLG4Aa text-2.0.2
    unordered-containers-0.2.20.1-IS42DvcTPVH3F2RDVwits
    vector-0.13.2.0-1mI63yzxbUH28Wn11C5uSI

haddock-interfaces:
    /usr/share/doc/haskell-aeson-pretty/html/aeson-pretty.haddock

haddock-html:         /usr/share/doc/haskell-aeson-pretty/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

